yt.utilities.minimal\_representation module
===========================================

.. automodule:: yt.utilities.minimal_representation
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:
